# camSort

Working on `python 3.7.1`!

`camSort` is a Python library that makes sorted() look slow while also using sorted(). It's built on Cython, and provides preallocation to string sorting by using a custom key calculation for each string. Normal key calculation and object creation are often computationally expensive—but here we optimize that with Cython >:)!

## Overview

The `camSort` library sorts a list of strings by creating a custom object for each string. This custom object, `StringWithKey`, holds the string and a unique key calculated from it. The key is a long integer derived from the sum of Unicode code points of the characters in the string, and the string's length.

The actual sorting operation uses Python's built-in `sorted` function (based on Timsort), however, now with precalculated keys, rather than comparing the strings themselves. Making sorting quite faster.

The primary benefit of using `camSort` is realized when working with very large lists of strings, see: Performance).

## Installation

## Usage

```python
import camSort
# or
from camSort import sortStrings

myList = ['your', 'list', 'of', 'strings', ':)!']

sortedStrings = camSort.sortStrings(myList)
# or
sortedStrings = sortStrings(myList)

```

## Performance

Average output on my 2017 macbook pro:
    (1 million strings, with a random legnth of 1 to 1000 chararacters)

Time taken by Python sorted(): 56.08621883392334 seconds
Time taken by camSort: 6.356221914291382 seconds